@@ -14,12 +14,7 @@ def create(args):
 
     # Duplicate server code onto /tmp
     check_output(['rm', '-rf', legion['tmp_server_path']])
-    check_output(['cp', '-r', legion['server_path'], '/tmp/legion-server'])
-
-    # Git init this
-    check_output(['git', 'init'], cwd=legion['tmp_server_path'])
-    check_output(['git', 'add', '.'], cwd=legion['tmp_server_path'])
-    check_output(['git', 'commit', '-m', '"Load balancer"'], cwd=legion['tmp_server_path'])
+    check_output(['git', 'clone', 'https://github.com/pmdartus/legion-load-balancer.git', '/tmp/legion-server'])
 
     # Config heroku
     print "Creating balancer server, name `%s`" % repo['heroku_name']
