@@ -4,8 +4,8 @@ import sys
 from subprocess import check_output, CalledProcessError
 
 from commands.create import create
-from commands.scale import scale
 from commands.destroy import destroy
+from commands.scale import scale
 
 def check_validity():
     """
@@ -18,11 +18,12 @@ def check_validity():
         sys.exit("Not a git repository")
 
 
-def main(args):
+def main():
     """
     Dispatch command to correct function
     """
-
+    args = sys.argv
+    
     check_validity()
 
     commands = {
@@ -39,4 +40,4 @@ def main(args):
     commands[args[1]](args[2:])
 
 if __name__ == '__main__':
-    main(sys.argv)
+    main()
